@@ -33,24 +33,24 @@ from mimetypes import MimeTypes
 from pathlib import Path
 from typing import Union, List, Optional, Callable, AsyncGenerator
 
-import darmilibs
-from darmilibs import __version__, __license__
-from darmilibs import enums
-from darmilibs import raw
-from darmilibs import utils
-from darmilibs.crypto import aes
-from darmilibs.errors import CDNFileHashMismatch
-from darmilibs.errors import (
+import geezlibs
+from geezlibs import __version__, __license__
+from geezlibs import enums
+from geezlibs import raw
+from geezlibs import utils
+from geezlibs.crypto import aes
+from geezlibs.errors import CDNFileHashMismatch
+from geezlibs.errors import (
     SessionPasswordNeeded,
     VolumeLocNotFound, ChannelPrivate,
     AuthBytesInvalid, BadRequest, ListenerCanceled
 )
-from darmilibs.handlers.handler import Handler
-from darmilibs.methods import Methods
-from darmilibs.session import Auth, Session
-from darmilibs.storage import FileStorage, MemoryStorage
-from darmilibs.types import User, TermsOfService
-from darmilibs.utils import ainput
+from geezlibs.handlers.handler import Handler
+from geezlibs.methods import Methods
+from geezlibs.session import Auth, Session
+from geezlibs.storage import FileStorage, MemoryStorage
+from geezlibs.types import User, TermsOfService
+from geezlibs.utils import ginput
 from .dispatcher import Dispatcher
 from .file_id import FileId, FileType, ThumbnailSource
 from .mime_types import mime_types
@@ -116,7 +116,7 @@ class Client(Methods):
         in_memory (``bool``, *optional*):
             Pass True to start an in-memory session that will be discarded as soon as the client stops.
             In order to reconnect again using an in-memory session without having to login again, you can use
-            :meth:`~darmilibs.Client.export_session_string` before stopping the client to get a session string you can
+            :meth:`~geezlibs.Client.export_session_string` before stopping the client to get a session string you can
             pass to the ``session_string`` parameter.
             Defaults to False.
 
@@ -144,7 +144,7 @@ class Client(Methods):
         plugins (``dict``, *optional*):
             Smart Plugins settings as dict, e.g.: *dict(root="plugins")*.
 
-        parse_mode (:obj:`~darmilibs.enums.ParseMode`, *optional*):
+        parse_mode (:obj:`~geezlibs.enums.ParseMode`, *optional*):
             Set the global parse mode of the client. By default, texts are parsed using both Markdown and HTML styles.
             You can combine both syntaxes together.
 
@@ -339,12 +339,12 @@ class Client(Methods):
             try:
                 if not self.phone_number:
                     while True:
-                        value = await ainput("Enter phone number or bot token: ")
+                        value = await ginput("Enter phone number or bot token: ")
 
                         if not value:
                             continue
 
-                        confirm = (await ainput(f'Is "{value}" correct? (y/N): ')).lower()
+                        confirm = (await ginput(f'Is "{value}" correct? (y/N): ')).lower()
 
                         if confirm == "y":
                             break
@@ -374,7 +374,7 @@ class Client(Methods):
 
         while True:
             if not self.phone_code:
-                self.phone_code = await ainput("Enter confirmation code: ")
+                self.phone_code = await ginput("Enter confirmation code: ")
 
             try:
                 signed_in = await self.sign_in(self.phone_number, sent_code.phone_code_hash, self.phone_code)
@@ -388,18 +388,18 @@ class Client(Methods):
                     print("Password hint: {}".format(await self.get_password_hint()))
 
                     if not self.password:
-                        self.password = await ainput("Enter password (empty to recover): ", hide=self.hide_password)
+                        self.password = await ginput("Enter password (empty to recover): ", hide=self.hide_password)
 
                     try:
                         if not self.password:
-                            confirm = await ainput("Confirm password recovery (y/n): ")
+                            confirm = await ginput("Confirm password recovery (y/n): ")
 
                             if confirm == "y":
                                 email_pattern = await self.send_recovery_code()
                                 print(f"The recovery code has been sent to {email_pattern}")
 
                                 while True:
-                                    recovery_code = await ainput("Enter recovery code: ")
+                                    recovery_code = await ginput("Enter recovery code: ")
 
                                     try:
                                         return await self.recover_password(recovery_code)
@@ -422,8 +422,8 @@ class Client(Methods):
             return signed_in
 
         while True:
-            first_name = await ainput("Enter first name: ")
-            last_name = await ainput("Enter last name (empty to skip): ")
+            first_name = await ginput("Enter first name: ")
+            last_name = await ginput("Enter last name (empty to skip): ")
 
             try:
                 signed_up = await self.sign_up(
@@ -450,14 +450,14 @@ class Client(Methods):
         global value by default.
 
         Parameters:
-            parse_mode (:obj:`~darmilibs.enums.ParseMode`):
+            parse_mode (:obj:`~geezlibs.enums.ParseMode`):
                 By default, texts are parsed using both Markdown and HTML styles.
                 You can combine both syntaxes together.
 
         Example:
             .. code-block:: python
 
-                from darmilibs import enums
+                from geezlibs import enums
 
                 # Default combined mode: Markdown + HTML
                 await app.send_message("me", "1. **markdown** and <i>html</i>")
@@ -629,13 +629,13 @@ class Client(Methods):
                 else:
                     while True:
                         try:
-                            value = int(await ainput("Enter the api_id part of the API key: "))
+                            value = int(await ginput("Enter the api_id part of the API key: "))
 
                             if value <= 0:
                                 print("Invalid value")
                                 continue
 
-                            confirm = (await ainput(f'Is "{value}" correct? (y/N): ')).lower()
+                            confirm = (await ginput(f'Is "{value}" correct? (y/N): ')).lower()
 
                             if confirm == "y":
                                 await self.storage.api_id(value)
@@ -1011,7 +1011,7 @@ class Client(Methods):
                             break
                 except Exception as e:
                     raise e
-        except darmilibs.StopTransmission:
+        except geezlibs.StopTransmission:
             raise
         except Exception as e:
             log.error(e, exc_info=True)
