@@ -22,7 +22,7 @@ from .auto_name import AutoName
 
 
 class ChatMemberStatus(AutoName):
-    """Chat member status enumeration used in :obj:`~darmilibs.types.ChatMember`."""
+    """Chat member status enumeration used in :obj:`~geezlibs.types.ChatMember`."""
 
     OWNER = auto()
     "Chat owner"
