@@ -16,12 +16,12 @@
 #  You should have received a copy of the GNU Lesser General Public License
 #  along with Pyrogram.  If not, see <http://www.gnu.org/licenses/>.
 
-from darmilibs import raw
+from geezlibs import raw
 from .auto_name import AutoName
 
 
 class ChatMembersFilter(AutoName):
-    """Chat members filter enumeration used in :meth:`~darmilibs.Client.get_chat_members`"""
+    """Chat members filter enumeration used in :meth:`~geezlibs.Client.get_chat_members`"""
 
     SEARCH = raw.types.ChannelParticipantsSearch
     "Search for members"
