@@ -16,13 +16,13 @@
 #  You should have received a copy of the GNU Lesser General Public License
 #  along with Pyrogram.  If not, see <http://www.gnu.org/licenses/>.
 
-import darmilibs
-from darmilibs import raw
+import geezlibs
+from geezlibs import raw
 
 
 class AcceptTermsOfService:
     async def accept_terms_of_service(
-        self: "darmilibs.Client",
+        self: "geezlibs.Client",
         terms_of_service_id: str
     ) -> bool:
         """Accept the given terms of service.
