@@ -18,15 +18,15 @@
 
 import logging
 
-import darmilibs
-from darmilibs import raw
+import geezlibs
+from geezlibs import raw
 
 log = logging.getLogger(__name__)
 
 
 class SendRecoveryCode:
     async def send_recovery_code(
-        self: "darmilibs.Client",
+        self: "geezlibs.Client",
     ) -> str:
         """Send a code to your email to recover your password.
 
