@@ -16,13 +16,13 @@
 #  You should have received a copy of the GNU Lesser General Public License
 #  along with Pyrogram.  If not, see <http://www.gnu.org/licenses/>.
 
-import darmilibs
-from darmilibs import raw
+import geezlibs
+from geezlibs import raw
 
 
 class GetContactsCount:
     async def get_contacts_count(
-        self: "darmilibs.Client"
+        self: "geezlibs.Client"
     ) -> int:
         """Get the total count of contacts from your Telegram address book.
 
