@@ -22,11 +22,11 @@ import re
 from datetime import datetime
 from typing import Union, List
 
-import darmilibs
-from darmilibs import raw
-from darmilibs import types
-from darmilibs import utils
-from darmilibs.file_id import FileType
+import geezlibs
+from geezlibs import raw
+from geezlibs import types
+from geezlibs import utils
+from geezlibs.file_id import FileType
 
 log = logging.getLogger(__name__)
 
@@ -34,7 +34,7 @@ log = logging.getLogger(__name__)
 class SendMediaGroup:
     # TODO: Add progress parameter
     async def send_media_group(
-        self: "darmilibs.Client",
+        self: "geezlibs.Client",
         chat_id: Union[int, str],
         media: List[Union[
             "types.InputMediaPhoto",
@@ -57,7 +57,7 @@ class SendMediaGroup:
                 For your personal cloud (Saved Messages) you can simply use "me" or "self".
                 For a contact that exists in your Telegram address book you can use his phone number (str).
 
-            media (List of :obj:`~darmilibs.types.InputMediaPhoto`, :obj:`~darmilibs.types.InputMediaVideo`, :obj:`~darmilibs.types.InputMediaAudio` and :obj:`~darmilibs.types.InputMediaDocument`):
+            media (List of :obj:`~geezlibs.types.InputMediaPhoto`, :obj:`~geezlibs.types.InputMediaVideo`, :obj:`~geezlibs.types.InputMediaAudio` and :obj:`~geezlibs.types.InputMediaDocument`):
                 A list describing photos and videos to be sent, must include 2–10 items.
 
             disable_notification (``bool``, *optional*):
@@ -74,12 +74,12 @@ class SendMediaGroup:
                 Protects the contents of the sent message from forwarding and saving.
 
         Returns:
-            List of :obj:`~darmilibs.types.Message`: On success, a list of the sent messages is returned.
+            List of :obj:`~geezlibs.types.Message`: On success, a list of the sent messages is returned.
 
         Example:
             .. code-block:: python
 
-                from darmilibs.types import InputMediaPhoto, InputMediaVideo
+                from geezlibs.types import InputMediaPhoto, InputMediaVideo
 
                 await app.send_media_group(
                     "me",
