@@ -10,16 +10,24 @@
 class First:
     ALIVE = "`Menunjukan Jati diri 🤖`"
     REPO = """
-**Hey**, __I am Robot__ ⭐ **DarmiPyro-Bot** ⭐
+**Hey**, __I am Robot__ ⭐ **RamPyro-Bot** ⭐
 
 ⭐ **Userbot Version :** `{}`
-⭐ **Group Support :** [Darmi Support Group](t.me/medsupportt)
-⭐ **Channel Rama :** [Gabutan Hamba](t.me/gabutanhamba)
-⭐ **Owner Repo :** [Hamba](t.me/kenapatagdar)
+⭐ **Group Support :** [Ram Support Group](t.me/GeezRam)
+⭐ **Channel Rama :** [Story Rama](t.me/k0kb4c0de)
+⭐ **Owner Repo :** [Rama](t.me/thisrama)
+⭐ **Repo :** [RamPyro-Bot](https://github.com/ramadhani892/RamPyro-Bot)
+⭐ **Donasi :** [VIA LINK](https://trakteer.id/ramadhani892)
 ⭐ **STRING :** [VIA WEB](https://replit.com/@dashezup/generate-pyrogram-session-string)
-⭐ **DarmiPyro-Bot Menyala** ⭐
+
+
+DEPLOY [VIA HEROKU](https://telegram.dog/XTZ_HerokuBot?start=cmFtYWRoYW5pODkyL1JhbVB5cm8tQm90IGRyYWdvbnM)"""
+    CREATOR = 'I was created by my master <a href="https://github.com/ramadhani892/RamPyro-Bot">Ram</a> on a rainy day.'
+    MSG_ON = """
+⭐ **RamPyro-Bot Menyala** ⭐
 ━━
 ➠ **Userbot Version -** `{}`
+➠ **Ketik** `{}rama` **untuk Mengecheck Bot**
 ━━
 """
 
