@@ -16,8 +16,8 @@
 #  You should have received a copy of the GNU Lesser General Public License
 #  along with Pyrogram.  If not, see <http://www.gnu.org/licenses/>.
 
-import darmilibs
-from darmilibs import raw
+import geezlibs
+from geezlibs import raw
 from .bot_command_scope import BotCommandScope
 
 
@@ -28,5 +28,5 @@ class BotCommandScopeAllPrivateChats(BotCommandScope):
     def __init__(self):
         super().__init__("all_private_chats")
 
-    async def write(self, client: "darmilibs.Client") -> "raw.base.BotCommandScope":
+    async def write(self, client: "geezlibs.Client") -> "raw.base.BotCommandScope":
         return raw.types.BotCommandScopeUsers()
