@@ -16,13 +16,13 @@
 #  You should have received a copy of the GNU Lesser General Public License
 #  along with Pyrogram.  If not, see <http://www.gnu.org/licenses/>.
 
-import darmilibs
+import geezlibs
 
 from ..object import Object
 
-"""- :obj:`~darmilibs.types.InputLocationMessageContent`
-    - :obj:`~darmilibs.types.InputVenueMessageContent`
-    - :obj:`~darmilibs.types.InputContactMessageContent`"""
+"""- :obj:`~geezlibs.types.InputLocationMessageContent`
+    - :obj:`~geezlibs.types.InputVenueMessageContent`
+    - :obj:`~geezlibs.types.InputContactMessageContent`"""
 
 
 class InputMessageContent(Object):
@@ -30,11 +30,11 @@ class InputMessageContent(Object):
 
     Pyrogram currently supports the following types:
 
-    - :obj:`~darmilibs.types.InputTextMessageContent`
+    - :obj:`~geezlibs.types.InputTextMessageContent`
     """
 
     def __init__(self):
         super().__init__()
 
-    async def write(self, client: "darmilibs.Client", reply_markup):
+    async def write(self, client: "geezlibs.Client", reply_markup):
         raise NotImplementedError
