@@ -27,4 +27,4 @@ class List(list):
         return Object.__str__(self)
 
     def __repr__(self):
-        return f"darmilibs.types.List([{','.join(Object.__repr__(i) for i in self)}])"
+        return f"geezlibs.types.List([{','.join(Object.__repr__(i) for i in self)}])"
