@@ -16,8 +16,8 @@
 #  You should have received a copy of the GNU Lesser General Public License
 #  along with Pyrogram.  If not, see <http://www.gnu.org/licenses/>.
 
-import darmilibs
-from darmilibs import raw
+import geezlibs
+from geezlibs import raw
 from ..object import Object
 
 
@@ -32,7 +32,7 @@ class StrippedThumbnail(Object):
     def __init__(
         self,
         *,
-        client: "darmilibs.Client" = None,
+        client: "geezlibs.Client" = None,
         data: bytes
     ):
         super().__init__(client)
