@@ -19,10 +19,10 @@
 from datetime import datetime
 from typing import Union, List, Optional, AsyncGenerator, BinaryIO
 
-import darmilibs
-from darmilibs import raw, enums
-from darmilibs import types
-from darmilibs import utils
+import geezlibs
+from geezlibs import raw, enums
+from geezlibs import types
+from geezlibs import utils
 from ..object import Object
 
 
@@ -33,7 +33,7 @@ class Chat(Object):
         id (``int``):
             Unique identifier for this chat.
 
-        type (:obj:`~darmilibs.enums.ChatType`):
+        type (:obj:`~geezlibs.enums.ChatType`):
             Type of chat.
 
         is_verified (``bool``, *optional*):
@@ -67,16 +67,16 @@ class Chat(Object):
         last_name (``str``, *optional*):
             Last name of the other party in a private chat, for private chats.
 
-        photo (:obj:`~darmilibs.types.ChatPhoto`, *optional*):
+        photo (:obj:`~geezlibs.types.ChatPhoto`, *optional*):
             Chat photo. Suitable for downloads only.
 
         bio (``str``, *optional*):
             Bio of the other party in a private chat.
-            Returned only in :meth:`~darmilibs.Client.get_chat`.
+            Returned only in :meth:`~geezlibs.Client.get_chat`.
 
         description (``str``, *optional*):
             Description, for groups, supergroups and channel chats.
-            Returned only in :meth:`~darmilibs.Client.get_chat`.
+            Returned only in :meth:`~geezlibs.Client.get_chat`.
 
         dc_id (``int``, *optional*):
             The chat assigned DC (data center). Available only in case the chat has a photo.
@@ -89,52 +89,52 @@ class Chat(Object):
 
         invite_link (``str``, *optional*):
             Chat invite link, for groups, supergroups and channels.
-            Returned only in :meth:`~darmilibs.Client.get_chat`.
+            Returned only in :meth:`~geezlibs.Client.get_chat`.
 
-        pinned_message (:obj:`~darmilibs.types.Message`, *optional*):
+        pinned_message (:obj:`~geezlibs.types.Message`, *optional*):
             Pinned message, for groups, supergroups channels and own chat.
-            Returned only in :meth:`~darmilibs.Client.get_chat`.
+            Returned only in :meth:`~geezlibs.Client.get_chat`.
 
         sticker_set_name (``str``, *optional*):
             For supergroups, name of group sticker set.
-            Returned only in :meth:`~darmilibs.Client.get_chat`.
+            Returned only in :meth:`~geezlibs.Client.get_chat`.
 
         can_set_sticker_set (``bool``, *optional*):
             True, if the group sticker set can be changed by you.
-            Returned only in :meth:`~darmilibs.Client.get_chat`.
+            Returned only in :meth:`~geezlibs.Client.get_chat`.
 
         members_count (``int``, *optional*):
             Chat members count, for groups, supergroups and channels only.
-            Returned only in :meth:`~darmilibs.Client.get_chat`.
+            Returned only in :meth:`~geezlibs.Client.get_chat`.
 
-        restrictions (List of :obj:`~darmilibs.types.Restriction`, *optional*):
+        restrictions (List of :obj:`~geezlibs.types.Restriction`, *optional*):
             The list of reasons why this chat might be unavailable to some users.
             This field is available only in case *is_restricted* is True.
 
-        permissions (:obj:`~darmilibs.types.ChatPermissions` *optional*):
+        permissions (:obj:`~geezlibs.types.ChatPermissions` *optional*):
             Default chat member permissions, for groups and supergroups.
 
         distance (``int``, *optional*):
             Distance in meters of this group chat from your location.
-            Returned only in :meth:`~darmilibs.Client.get_nearby_chats`.
+            Returned only in :meth:`~geezlibs.Client.get_nearby_chats`.
 
-        linked_chat (:obj:`~darmilibs.types.Chat`, *optional*):
+        linked_chat (:obj:`~geezlibs.types.Chat`, *optional*):
             The linked discussion group (in case of channels) or the linked channel (in case of supergroups).
-            Returned only in :meth:`~darmilibs.Client.get_chat`.
+            Returned only in :meth:`~geezlibs.Client.get_chat`.
 
-        send_as_chat (:obj:`~darmilibs.types.Chat`, *optional*):
+        send_as_chat (:obj:`~geezlibs.types.Chat`, *optional*):
             The default "send_as" chat.
-            Returned only in :meth:`~darmilibs.Client.get_chat`.
+            Returned only in :meth:`~geezlibs.Client.get_chat`.
 
-        available_reactions (:obj:`~darmilibs.types.ChatReactions`, *optional*):
+        available_reactions (:obj:`~geezlibs.types.ChatReactions`, *optional*):
             Available reactions in the chat.
-            Returned only in :meth:`~darmilibs.Client.get_chat`.
+            Returned only in :meth:`~geezlibs.Client.get_chat`.
     """
 
     def __init__(
         self,
         *,
-        client: "darmilibs.Client" = None,
+        client: "geezlibs.Client" = None,
         id: int,
         type: "enums.ChatType",
         is_verified: bool = None,
@@ -368,7 +368,7 @@ class Chat(Object):
         return self._client.cancel_listener(self.id)
 
     async def archive(self):
-        """Bound method *archive* of :obj:`~darmilibs.types.Chat`.
+        """Bound method *archive* of :obj:`~geezlibs.types.Chat`.
 
         Use as a shortcut for:
 
@@ -391,7 +391,7 @@ class Chat(Object):
         return await self._client.archive_chats(self.id)
 
     async def unarchive(self):
-        """Bound method *unarchive* of :obj:`~darmilibs.types.Chat`.
+        """Bound method *unarchive* of :obj:`~geezlibs.types.Chat`.
 
         Use as a shortcut for:
 
@@ -415,7 +415,7 @@ class Chat(Object):
 
     # TODO: Remove notes about "All Members Are Admins" for basic groups, the attribute doesn't exist anymore
     async def set_title(self, title: str) -> bool:
-        """Bound method *set_title* of :obj:`~darmilibs.types.Chat`.
+        """Bound method *set_title* of :obj:`~geezlibs.types.Chat`.
 
         Use as a shortcut for:
 
@@ -453,7 +453,7 @@ class Chat(Object):
         )
 
     async def set_description(self, description: str) -> bool:
-        """Bound method *set_description* of :obj:`~darmilibs.types.Chat`.
+        """Bound method *set_description* of :obj:`~geezlibs.types.Chat`.
 
         Use as a shortcut for:
 
@@ -493,7 +493,7 @@ class Chat(Object):
         video: Union[str, BinaryIO] = None,
         video_start_ts: float = None,
     ) -> bool:
-        """Bound method *set_photo* of :obj:`~darmilibs.types.Chat`.
+        """Bound method *set_photo* of :obj:`~geezlibs.types.Chat`.
 
         Use as a shortcut for:
 
@@ -522,12 +522,12 @@ class Chat(Object):
 
         Parameters:
             photo (``str`` | ``BinaryIO``, *optional*):
-                New chat photo. You can pass a :obj:`~darmilibs.types.Photo` file_id, a file path to upload a new photo
+                New chat photo. You can pass a :obj:`~geezlibs.types.Photo` file_id, a file path to upload a new photo
                 from your local machine or a binary file-like object with its attribute
                 ".name" set for in-memory uploads.
 
             video (``str`` | ``BinaryIO``, *optional*):
-                New chat video. You can pass a :obj:`~darmilibs.types.Video` file_id, a file path to upload a new video
+                New chat video. You can pass a :obj:`~geezlibs.types.Video` file_id, a file path to upload a new video
                 from your local machine or a binary file-like object with its attribute
                 ".name" set for in-memory uploads.
 
@@ -554,7 +554,7 @@ class Chat(Object):
         user_id: Union[int, str],
         until_date: datetime = utils.zero_datetime()
     ) -> Union["types.Message", bool]:
-        """Bound method *ban_member* of :obj:`~darmilibs.types.Chat`.
+        """Bound method *ban_member* of :obj:`~geezlibs.types.Chat`.
 
         Use as a shortcut for:
 
@@ -586,7 +586,7 @@ class Chat(Object):
                 considered to be banned forever. Defaults to epoch (ban forever).
 
         Returns:
-            :obj:`~darmilibs.types.Message` | ``bool``: On success, a service message will be returned (when applicable), otherwise, in
+            :obj:`~geezlibs.types.Message` | ``bool``: On success, a service message will be returned (when applicable), otherwise, in
             case a message object couldn't be returned, True is returned.
 
         Raises:
@@ -603,7 +603,7 @@ class Chat(Object):
         self,
         user_id: Union[int, str]
     ) -> bool:
-        """Bound method *unban_member* of :obj:`~darmilibs.types.Chat`.
+        """Bound method *unban_member* of :obj:`~geezlibs.types.Chat`.
 
         Use as a shortcut for:
 
@@ -642,7 +642,7 @@ class Chat(Object):
         permissions: "types.ChatPermissions",
         until_date: datetime = utils.zero_datetime(),
     ) -> "types.Chat":
-        """Bound method *unban_member* of :obj:`~darmilibs.types.Chat`.
+        """Bound method *unban_member* of :obj:`~geezlibs.types.Chat`.
 
         Use as a shortcut for:
 
@@ -664,7 +664,7 @@ class Chat(Object):
                 Unique identifier (int) or username (str) of the target user.
                 For a contact that exists in your Telegram address book you can use his phone number (str).
 
-            permissions (:obj:`~darmilibs.types.ChatPermissions`):
+            permissions (:obj:`~geezlibs.types.ChatPermissions`):
                 New user permissions.
 
             until_date (:py:obj:`~datetime.datetime`, *optional*):
@@ -673,7 +673,7 @@ class Chat(Object):
                 considered to be banned forever. Defaults to epoch (ban forever).
 
         Returns:
-            :obj:`~darmilibs.types.Chat`: On success, a chat object is returned.
+            :obj:`~geezlibs.types.Chat`: On success, a chat object is returned.
 
         Raises:
             RPCError: In case of a Telegram RPC error.
@@ -693,7 +693,7 @@ class Chat(Object):
         user_id: Union[int, str],
         privileges: "types.ChatPrivileges" = None
     ) -> bool:
-        """Bound method *promote_member* of :obj:`~darmilibs.types.Chat`.
+        """Bound method *promote_member* of :obj:`~geezlibs.types.Chat`.
 
         Use as a shortcut for:
 
@@ -715,7 +715,7 @@ class Chat(Object):
                 Unique identifier (int) or username (str) of the target user.
                 For a contact that exists in your Telegram address book you can use his phone number (str).
 
-            privileges (:obj:`~darmilibs.types.ChatPrivileges`, *optional*):
+            privileges (:obj:`~geezlibs.types.ChatPrivileges`, *optional*):
                 New user privileges.
 
         Returns:
@@ -732,7 +732,7 @@ class Chat(Object):
         )
 
     async def join(self):
-        """Bound method *join* of :obj:`~darmilibs.types.Chat`.
+        """Bound method *join* of :obj:`~geezlibs.types.Chat`.
 
         Use as a shortcut for:
 
@@ -749,7 +749,7 @@ class Chat(Object):
             This only works for public groups, channels that have set a username or linked chats.
 
         Returns:
-            :obj:`~darmilibs.types.Chat`: On success, a chat object is returned.
+            :obj:`~geezlibs.types.Chat`: On success, a chat object is returned.
 
         Raises:
             RPCError: In case of a Telegram RPC error.
@@ -758,7 +758,7 @@ class Chat(Object):
         return await self._client.join_chat(self.username or self.id)
 
     async def leave(self):
-        """Bound method *leave* of :obj:`~darmilibs.types.Chat`.
+        """Bound method *leave* of :obj:`~geezlibs.types.Chat`.
 
         Use as a shortcut for:
 
@@ -778,7 +778,7 @@ class Chat(Object):
         return await self._client.leave_chat(self.id)
 
     async def export_invite_link(self):
-        """Bound method *export_invite_link* of :obj:`~darmilibs.types.Chat`.
+        """Bound method *export_invite_link* of :obj:`~geezlibs.types.Chat`.
 
         Use as a shortcut for:
 
@@ -804,7 +804,7 @@ class Chat(Object):
         self,
         user_id: Union[int, str],
     ) -> "types.ChatMember":
-        """Bound method *get_member* of :obj:`~darmilibs.types.Chat`.
+        """Bound method *get_member* of :obj:`~geezlibs.types.Chat`.
 
         Use as a shortcut for:
 
@@ -821,7 +821,7 @@ class Chat(Object):
                 await chat.get_member(user_id)
 
         Returns:
-            :obj:`~darmilibs.types.ChatMember`: On success, a chat member is returned.
+            :obj:`~geezlibs.types.ChatMember`: On success, a chat member is returned.
         """
 
         return await self._client.get_chat_member(
@@ -835,7 +835,7 @@ class Chat(Object):
         limit: int = 0,
         filter: "enums.ChatMembersFilter" = enums.ChatMembersFilter.SEARCH
     ) -> Optional[AsyncGenerator["types.ChatMember", None]]:
-        """Bound method *get_members* of :obj:`~darmilibs.types.Chat`.
+        """Bound method *get_members* of :obj:`~geezlibs.types.Chat`.
 
         Use as a shortcut for:
 
@@ -854,19 +854,19 @@ class Chat(Object):
             query (``str``, *optional*):
                 Query string to filter members based on their display names and usernames.
                 Only applicable to supergroups and channels. Defaults to "" (empty string).
-                A query string is applicable only for :obj:`~darmilibs.enums.ChatMembersFilter.SEARCH`,
-                :obj:`~darmilibs.enums.ChatMembersFilter.BANNED` and :obj:`~darmilibs.enums.ChatMembersFilter.RESTRICTED`
+                A query string is applicable only for :obj:`~geezlibs.enums.ChatMembersFilter.SEARCH`,
+                :obj:`~geezlibs.enums.ChatMembersFilter.BANNED` and :obj:`~geezlibs.enums.ChatMembersFilter.RESTRICTED`
                 filters only.
 
             limit (``int``, *optional*):
                 Limits the number of members to be retrieved.
 
-            filter (:obj:`~darmilibs.enums.ChatMembersFilter`, *optional*):
+            filter (:obj:`~geezlibs.enums.ChatMembersFilter`, *optional*):
                 Filter used to select the kind of members you want to retrieve. Only applicable for supergroups
                 and channels.
 
         Returns:
-            ``Generator``: On success, a generator yielding :obj:`~darmilibs.types.ChatMember` objects is returned.
+            ``Generator``: On success, a generator yielding :obj:`~geezlibs.types.ChatMember` objects is returned.
         """
 
         return self._client.get_chat_members(
@@ -881,7 +881,7 @@ class Chat(Object):
         user_ids: Union[Union[int, str], List[Union[int, str]]],
         forward_limit: int = 100
     ) -> bool:
-        """Bound method *add_members* of :obj:`~darmilibs.types.Chat`.
+        """Bound method *add_members* of :obj:`~geezlibs.types.Chat`.
 
         Use as a shortcut for:
 
@@ -905,7 +905,7 @@ class Chat(Object):
         )
 
     async def mark_unread(self, ) -> bool:
-        """Bound method *mark_unread* of :obj:`~darmilibs.types.Chat`.
+        """Bound method *mark_unread* of :obj:`~geezlibs.types.Chat`.
 
         Use as a shortcut for:
 
@@ -925,7 +925,7 @@ class Chat(Object):
         return await self._client.mark_chat_unread(self.id)
 
     async def set_protected_content(self, enabled: bool) -> bool:
-        """Bound method *set_protected_content* of :obj:`~darmilibs.types.Chat`.
+        """Bound method *set_protected_content* of :obj:`~geezlibs.types.Chat`.
 
         Use as a shortcut for:
 
@@ -952,7 +952,7 @@ class Chat(Object):
         )
 
     async def unpin_all_messages(self) -> bool:
-        """Bound method *unpin_all_messages* of :obj:`~darmilibs.types.Chat`.
+        """Bound method *unpin_all_messages* of :obj:`~geezlibs.types.Chat`.
 
         Use as a shortcut for:
 
